@@ -370,13 +370,20 @@ class bdata(mdata):
             "ILE2:BIASTUBE:"                            :"biastube", 
             "ILE2:BIASTUBE:V"                           :"biastube", 
             "ILE2:BIASTUBE:VOL"                         :"biastube", 
+            "ILE2:BIASTUBE:RDVOL"                       :"biastube", 
              
-            "ILE2:DPPLR:CH0:HW:RDVOL"                   :"dopplertube", 
+            "ILE2:DPPLR:CH0:HW:RDVOL"                   :"dopplertube_ch0", 
+            "ILE2:DPPLR:CH1:HW:RDVOL"                   :"dopplertube_ch1", 
+            "ILE2:DPPLR:CH2:HW:RDVOL"                   :"dopplertube_ch2", 
              
             "ILE2A1:HH:CUR"                             :"hh_current", 
             "ILE2A1:HH:RDCU"                            :"hh_current", 
             "ILE2A1:HH:RDCUR"                           :"hh_current", 
             "ILE2A1:HH3:RDCUR"                          :"hh_current", 
+            
+            "TRILIS177:METER:LAMBDA1"                   :"las_lambda",
+            "TRILIS177:METER:WAVENUM1"                  :"las_wavenum",
+            
             "":""
             }
     
@@ -563,6 +570,12 @@ class bdata(mdata):
             # finalize file name
             run = '%06d.msr' % run_number
             filename = os.path.join(directory, str(year), run)
+
+            # check if file is link - follow the link
+            if os.path.islink(filename):
+                path = os.path.split(filename)[0]
+                filename = os.path.split(os.readlink(filename))[-1]
+                filename = os.path.join(path, filename)
             
             # if file does not exist, try to fetch from web
             if not os.path.isfile(filename):
@@ -1196,14 +1209,12 @@ class bdata(mdata):
         elif self.mode == '1d':
             xlabel = 'Laser'
         
+        if 'Custom EPICS scan' in self.hist.keys():
+            xlabel = 'Custom EPICS scan'
+        
         # get data
-        try:
-            return self.hist[xlabel].data
+        return self.hist[xlabel].data
             
-        # custom scan
-        except KeyError:
-            return self.hist['Custom EPICS scan'].data
-    
     # ======================================================================= #
     def _rebin(self, xdx, rebin):
         """
@@ -1622,6 +1633,8 @@ class bdata(mdata):
             
             # get xaxis label and data key
             xlab = self.mode1_dict[self.mode]
+            if 'Custom EPICS scan' in self.hist.keys():
+                xlab = 'custom'
             
             # deadtime correction
             d = self._correct_deadtime(d, deadtime)
